
========================================
Welcome to Django SHOP's documentation!
========================================

User Manual
============

The "instructions" :)

.. toctree::
    :maxdepth: 1
    :numbered:
    
    getting-started
    contributing

How to
======

Various short articles on how to do specific things

.. toctree::
    :maxdepth: 2
    :numbered:

    howto/how-to-product
    howto/how-to-cart-mod
    howto/how-to-payment
    howto/how-to-shipping

    
Reference
==========

Reference sheets and lists regarding django SHOP

.. toctree::
    :maxdepth: 1
    :numbered:
    
    settings